mafw.examples.processor\_list
=============================

.. automodule:: mafw.examples.processor_list

   
   .. rubric:: Functions

   .. autosummary::
   
      run_processor_list_with_loop_modifier
      run_simple_processor_list
   